<?php

	# 		Density Altitude
	# 		Namespace:		densityAltitude
	#		Meteotemplate Block
	
	# 		Version 2.0 - Jun 08, 2016
	#		- added station elevation
	#		- bug fixes
	
		
	// load theme
	$designTheme = json_decode(file_get_contents("../../css/theme.txt"),true);
	$theme = $designTheme['theme'];
	
	include("../../../config.php");
	include("../../../css/design.php");
	include("../../../scripts/functions.php");
	
	$languageRaw = file_get_contents($baseURL."lang/gb.php");
	$language['gb'] = json_decode($languageRaw,true);
	$languageRaw = file_get_contents($baseURL."lang/".$lang.".php");
	$language[$lang] = json_decode($languageRaw,true);
	
	if(file_exists("settings.php")){
		include("settings.php");
	}
	else{
		echo "Please go to your admin section and go through the settings for this block first.";
		die();
	}
	
	if($elevationUnits=="m"){
		$elevationM = $stationElevation;
		$elevationFT = round($stationElevation*3.28084,0);
	}
	else{
		$elevationM = round($stationElevation/3.28084,0);
		$elevationFT = $stationElevation;
	}
	
	$result = mysqli_query($con,"
		SELECT T, P, D
		FROM alldata 
		ORDER BY DateTime DESC
		LIMIT 1
		"
	);
	while($row = mysqli_fetch_array($result)){
		$currentT = $row['T'];
		$currentP = $row['P'];
		$currentD = $row['D'];
	}
	// convert
	if($dataTempUnits=="C"){
		$TF = ($currentT*1.8) + 32;
		$TC = $currentT;
		$TK = $currentT + 273.15;
		$DF = ($currentD*1.8) + 32;
		$DC = $currentD;
		$DK = $currentD + 273.15;
	}
	if($dataTempUnits=="F"){
		$TF = $currentT;
		$TC = ($currentT-32)/1.8;
		$TK = ($currentT + 459.67)/1.8;
		$DF = $currentT;
		$DC = ($currentT-32)/1.8;
		$DK = ($currentT + 459.67)/1.8;
	}
	if($dataPressUnits=="hpa"){
		$Pin = $currentP / 33.863886;
		$Phpa = $currentP;
	}
	if($dataPressUnits=="mmhg"){
		$Pin = $currentP * 0.0393702;
		$Phpa = $currentP * 1.3332239;
	}
	if($dataPressUnits=="inhg"){
		$Pin = $currentP;
		$Phpa = $currentP * 33.863886;
	}

	// vapor pressure
	$A = (7.5*$DC)/(237.7+$DC);
	$e = 6.11 * pow(10,$A);
	
	// virtual temperature
	$Tv = $TK / (1 - ($e/$Phpa) * (1-0.622));
	$TR = $Tv * 1.8;
	
	// density altitude
	$B = (17.326 * $Pin) / $TR;
	$DA = 145366 * (1 - pow($B,0.235));
	
	$TvC = $Tv - 273.15;
	$TvF = ($Tv - 273.15)* 1.8 + 32;

?>
	<style>
		
	</style>
	<img src="homepage/blocks/densityAltitude/icons/<?php echo $theme?>/da.png" style="width:50px">
	<h2><?php echo lang('density altitude','c')?></h2>
	<table style="width:98%;margin:0 auto">
		<tr>
			<td style="width:50%;font-size:1.4em;font-variant:small-caps;font-weight:bold;text-align:center">
				<?php echo number_format(($DA+$elevationFT),1,".","")?> ft
			</td>
			<td style="width:50%;font-size:1.4em;font-variant:small-caps;font-weight:bold;text-align:center">
				<?php echo number_format(($DA*0.3048 + $elevationM),1,".","")?> m
			</td>
		</tr>
		<tr>
			<td style="text-align:center;font-variant:small-caps" colspan="2">
				<strong><?php echo lang('station elevation','c')?></strong><br><?php echo $elevationM."m / ".$elevationFT."ft";?>
			</td>
		</tr>
		<tr>
			<td style="width:50%;font-size:0.9em;font-weight:bold;text-align:center">
				<br><?php echo lang('vapor pressure','c')."<br>".number_format($e,1,".","")." hPa / ".number_format(($e/ 33.863886),1,".","")." inHg";?>
			</td>
			<td style="width:50%;font-size:0.9em;font-weight:bold;text-align:center">
				<br><?php echo lang('virtual temperature','c')."<br>".number_format($TvC,1,".","")." °C / ".number_format($TvF,1,".","")." °F";?>
			</td>
		</tr>
	</table>
	
